import * as React from 'react';
import { ReportData, WorkflowMapping } from './report-data-typings';
import './Report.scss';
declare type Levels = 'Error' | 'Warning' | 'Info' | 'Fatal' | 'Critical';
export declare type Issues = 'Error' | 'Warning' | 'Info' | 'All';
export declare type Tables = 'files' | 'problems';
declare type AuditInfo = Partial<{
    level: Levels;
    category: string;
    message: string;
    type: string;
    fileName: string;
    filePath: string;
}>;
export declare const ReportContext: React.Context<{
    reportData: ReportData;
    workflowMapping?: WorkflowMapping | undefined;
    currentTable: Tables;
    setCurrentTable: (table: Tables | ((prev: Tables) => Tables)) => void;
    currentAuditInfo?: Partial<{
        level: Levels;
        category: string;
        message: string;
        type: string;
        fileName: string;
        filePath: string;
    }> | undefined;
    setCurrentAuditInfo: (auditInfo?: AuditInfo) => void;
    focusedIssue: Issues;
    setFocusedIssue: (issue: Issues) => void;
    focusedWorkflows: string[];
    setFocusedWorkflows: (issues: string[] | ((issues: string[]) => string[])) => void;
    activeRow: string;
    setActiveRow: React.Dispatch<React.SetStateAction<string>>;
} | undefined>;
/**
 * `Report` is the root component where the report data should be passed.
 *
 * When `children` are not specified, a default sensible layout is shown.
 *
 * For extra flexibility (e.g. custom layouts, localization), the individual components can be passed as `children`
 * along with any additional elements. The report data is made available to child components through context so that
 * it does not need to be passed individually.
 *
 * @example
 * <Report data={reportData} workflowMapping={workflowMapping}/>
 *
 * @example
 * <Report data={reportData} workflowMapping={workflowMapping}>
 *   <div style={{ display: 'flex' }}>
 *    <ReportTitle />
 *    <ReportDebugIds />
 *   </div>
 *   <ReportTableSelect />
 *   <ReportInfoPanelWrapper>
 *     <ReportTableView>
 *       <FilesTable />
 *       <ProblemsTable />
 *     </ReportTableView>
 *     <ReportInfoPanel />
 *   </ReportInfoPanelWrapper>
 * </Report>
 */
export declare const Report: ({ data, workflowMapping, children, className, }: {
    /** The report data should be compatible with the type definitions. */
    data: ReportData;
    workflowMapping?: WorkflowMapping | undefined;
    className?: string | undefined;
    children?: React.ReactNode;
}) => JSX.Element;
export default Report;
