import * as React from 'react';
import { Tables } from './Report';
import './ReportTableView.scss';
/**
 * `ReportTableView` shows the `FilesTable`, `ProblemsTable`, depending on the active selection.
 *
 * The `FilesTable`, `ProblemsTable`, can be passed as children with custom props (e.g. localization, custom icons).
 *
 * @example
 * <ReportTableView>
 *   <FilesTable displayStrings={{ ... }} />
 *   <ProblemsTable displayStrings={{ ... }} />
 * </ReportTableView>
 */
export declare const ReportTableView: ({ currentTable, children, className, ...rest }: {
    /**
     * Current table. Will be inferred from context if not specified.
     */
    currentTable?: Tables | undefined;
    /**
     * Two `children` can be specified to override the tables.
     * @default
     * [<FilesTable />, <ProblemsTable />]
     */
    children?: React.ReactNode[] | undefined;
    className?: string | undefined;
    id?: string | undefined;
}) => JSX.Element;
